@@ -9,7 +9,9 @@
 # Copyright ©2011-2025. Hunan xxxxxxx Company limited. All rights reserved.
 # ---------------------------------------------------------------------------------------------------------
 """
-from typing import List
+import asyncio
+from logging import Logger
+from typing import List, Any, cast
 from playwright.async_api import Page, Locator, TimeoutError as PlaywrightTimeoutError
 
 
@@ -63,21 +65,17 @@ class BasePo(object):
         :return: 元素对象
         :return:
         """
+        locator = self.__page.locator(selector)
         try:
-            locator = self.__page.locator(selector)
-            if await self.exists(locator=locator):
-                await locator.first.wait_for(state='visible', timeout=timeout * 1000)
-                return locator
-            else:
-                raise RuntimeError(f"根据selector: {selector}，在页面没有找到对应的元素")
+            await locator.first.wait_for(state='visible', timeout=timeout * 1000)
+            return locator
         except (PlaywrightTimeoutError,):
             raise PlaywrightTimeoutError(f"元素 '{selector}' 未在 {timeout} 秒内找到")
-        except (RuntimeError, ):
-            raise
         except Exception as e:
             raise RuntimeError(f"检查元素时发生错误: {str(e)}")
 
-    async def get_sub_locator(self, locator: Locator, selector: str, timeout: float = 3.0) -> Locator:
+    @staticmethod
+    async def get_sub_locator(locator: Locator, selector: str, timeout: float = 3.0) -> Locator:
         """
         获取页面locator的子locator
         :param locator: 页面Locator对象
@@ -86,16 +84,31 @@ class BasePo(object):
         :return: 元素对象
         :return:
         """
+        locator_inner = locator.locator(selector)
         try:
-            locator_inner = locator.locator(selector)
-            if await self.exists(locator=locator_inner):
-                await locator_inner.first.wait_for(state='visible', timeout=timeout * 1000)
-                return locator_inner
-            else:
-                raise RuntimeError(f"根据selector: {selector}，在页面Locator对象中没有查找对应的子Locator对象")
+            await locator_inner.first.wait_for(state='visible', timeout=timeout * 1000)
+            return locator_inner
         except (PlaywrightTimeoutError,):
             raise PlaywrightTimeoutError(f"元素 '{selector}' 未在 {timeout} 秒内找到")
-        except (RuntimeError, ):
-            raise
         except Exception as e:
             raise RuntimeError(f"检查元素时发生错误: {str(e)}")
+
+    @classmethod
+    async def handle_po_cookie_tip(cls, page: Any, logger: Logger, timeout: float = 3.0, selectors: List[str] = None) -> None:
+        selectors_inner: List[str] = [
+            '//div[@id="isReadedCookie"]/button',
+            '//button[@id="continue-btn"]/span[normalize-space(text())="同意"]'
+        ]
+        if selectors:
+            selectors_inner.extend(selectors)
+        for selector in selectors_inner:
+            try:
+                page_inner = cast(cls, page)
+                cookie: Locator = await cls.get_locator(self=page_inner, selector=selector, timeout=timeout)
+                logger.info(
+                    f'找到页面中存在cookie提示：[本网站使用cookie，用于在您的电脑中储存信息。这些cookie可以使网站正常运行，以及帮助我们改进用户体验。使用本网站，即表示您接受放置这些cookie。]')
+                await cookie.click(button="left")
+                logger.info("【同意】按钮点击完成")
+                await asyncio.sleep(1)
+            except (Exception,):
+                pass
